#
# spec file for package python-pip
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# NOTE(saschpe): git invocation and pythonpath issues with testrepository
# enable testing with a build conditional (off by default):
%bcond_with test

Name:           python-pip
Version:        9.0.1
Release:        0
Url:            http://www.pip-installer.org
Summary:        Pip installs packages. Python packages. An easy_install replacement
License:        MIT
Group:          Development/Languages/Python
Source:         https://pypi.io/packages/source/p/pip/pip-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
%if %{with test}
# Test requirements:
BuildRequires:  python-mock
BuildRequires:  python-pytest
BuildRequires:  python-scripttest >= 1.3
BuildRequires:  python-virtualenv >= 1.10
%endif
Requires:       coreutils
Requires:       python-setuptools
Requires:       python-xml
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-argparse
Requires:       python-argparse
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Pip is a replacement for easy_install. It uses mostly the same techniques for
finding packages, so packages that were made easy_installable should be
pip-installable as well.

%prep
%setup -q -n pip-%{version}
sed -i "s|#!/usr/bin/env python||g" pip/__init__.py # Fix non-executable script

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
rm %{buildroot}%{_bindir}/pip
ln -s %{_bindir}/pip%{py_ver} %{buildroot}%{_bindir}/pip

%if %{with test}
%check
python setup.py test
%endif

%pre
# Since /usr/bin/pip became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternatives-ified package:
[ -h %{_bindir}/pip ] || rm -f %{_bindir}/pip

%post
update-alternatives --install %{_bindir}/pip pip %{_bindir}/pip%{py_ver} 20

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove pip %{_bindir}/pip%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc AUTHORS.txt CHANGES.txt LICENSE.txt README.rst
%ghost %{_bindir}/pip
%{_bindir}/pip2
%{_bindir}/pip%{py_ver}
%{python_sitelib}/pip-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/pip
%if 0%{?suse_version} >= 1230
%ghost %{_sysconfdir}/alternatives/pip
%endif

%changelog
